<template>
    <div class="app-container">
        <div class="filter-container">
            <div class="carrier_search">
                <span>按单位名称查：</span>
                <el-input v-model="listQuery.filter.companyname" class="carrier_search_input"></el-input>
            </div>
            <div class="carrier_search">
                <span>按负责人姓名查：</span>
                <el-input v-model="listQuery.filter.name" class="carrier_search_input"></el-input>
            </div>
            <el-button  style="margin-left: 10px;" type="primary"  @click="openCarrierLisenceForm('新增','')">添加</el-button>
            <el-button  style="margin-left: 10px;" type="primary"  @click="searchData()">查询</el-button>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="carrierList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="单位名称" prop="companyname" align="center">
                </el-table-column>
                <el-table-column label="危险货物道路运输资质证号" prop="number" align="center">
                </el-table-column>
                <el-table-column label="负责人姓名" prop="name" align="center">
                </el-table-column>
                <el-table-column label="负责人联系电话" prop="phone" align="center">
                </el-table-column>
                <el-table-column label="道路运输证编号" prop="number" align="center">
                </el-table-column>
                <el-table-column label="证件有效期" prop="validtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center" width="180" class-name="small-padding fixed-width">
                    <template slot-scope="scope">
                        <el-button type="text" @click="openCarrierLisenceForm('修改',scope.row)">修改</el-button>
                        <el-button type="text" @click="deleteById('删除',scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
        <carrierForm ref="carrierForm" @getinfo="getCarrierData"></carrierForm>
    </div>
</template>

<script>
import carrierForm from "./components/carrierForm";
import { computePageCount } from '@/utils'
import { getCarrierData , deleteCarrier} from "../../api/carrier";

export default {
    name: "carrier",
    data(){
        return{
            tableKey:0,
            listLoading:false,
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            listQuery:{
              filter:{
                  name:'',
                  companyname:'',
              },
                pageIndex:1,
                pageSize:10,
            },
            searchContent:'',
            carrierList:[],
        }
    },
    components:{
        carrierForm
    },
    created(){
        this.getCarrierData()
    },
    methods:{
        async getCarrierData(){
            this.listLoading = true
            let res = await getCarrierData(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.total, res.data.result.size)
                this.currentPage = res.data.result.current
                this.carrierList = res.data.result.records
            }
            this.listLoading = false
        },
        deleteById(title,row){
            this.$confirm('删除此条信息，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
                deleteCarrier(row.id).then( ()=>{
                    this.getCarrierData()
                    this.$notify({
                        title:'成功',
                        message:'删除成功',
                        type:'success',
                        duration:2000,
                    })
                })
            })
        },
        openCarrierLisenceForm(title,value){
            this.$refs.carrierForm.showCarrierForm(title,value)
        },
        searchData(){
            this.getCarrierData()
        },
        handleSizeChange: function(val) {
            this.pageSize = val
            this.currentPage = 1
            this.getCarrierData()
        },
        handleCurrentChange: function(val) {
            this.currentPage = val
            this.getCarrierData()
        },
    }
}
</script>

<style scoped>
.carrier_search{
    display: inline-block;
}
.carrier_search_input{
    width:200px;
}
/deep/ .table_content{
    padding:0px;
}
</style>
